``glom`` by Analogy
===================

``glom`` is pure Python, and you don't need to know anything but
Python to use it effectively. But, chances are you do know other
things, and the sections below can help get you up to speed.

Similarity to list comprehensions, map, and remap
-------------------------------------------------

Similarity to templating (Jinja, Django, Mustache)
--------------------------------------------------

Similarity to SQL
-----------------

``glom``

Similiarity to validation (jsonschema, schema, cerberus)
--------------------------------------------------------
